@@ -307,6 +307,9 @@ class Saera:
 		struct = gst.Structure('partial_result')
 		struct.set_value('hyp', text)
 		struct.set_value('uttid', uttid)
+		if text.lower()=="open":
+			asr.set_property('lm', 'model_open/6521.lm')
+			asr.set_property('dict', 'model_open/6521.dic')
 		asr.post_message(gst.message_new_application(asr, struct))
 
 	def asr_result(self, asr, text, uttid):
