@@ -5,6 +5,7 @@ import datetime
 import time
 import gobject
 import os, sys
+import tempfile
 
 # Strings
 import sentences.sentences_english as sent
@@ -39,6 +40,8 @@ def parse_input(input):
 	
 	elif exists_in_order(['put','on','music'],input.split()) or exists_in_order(['play','music'],input.split()):
 		return play_music(), None
+	elif exists_in_order(['pause', 'music'],input.split()) or exists_in_order(['be','quiet'],input.split()):
+		return pause_music(), None
 	elif exists_in_order(['what', 'time'], input.split()):
 		return current_time(input), None
 	elif exists_in_order(['what', 'day'], input.split()):
@@ -47,8 +50,11 @@ def parse_input(input):
 		return take_picture(input)
 	elif exists_in_order(['answer','life','universe','everything'],input.split()) or exists_in_order(['meaning','life','universe','everything'],input.split()):
 		return life_the_universe_and_everything(), None
+
+	elif 'hungry' in input or set(sent.food).intersection(set(input.split())):
+		return food(input)
 		
-	elif exists_in_order(['my','location'],input.split()):
+	elif exists_in_order(['my','location'],input.split()) or exists_in_order(['where', 'i'],input.split()):
 		return where_am_i(input)
 		
 	elif input in ("quit ", "go away "):
@@ -66,8 +72,14 @@ def store_answer(answer):
 	
 def play_music():
 	#Todo.
+	os.system("dbus-send --dest=com.nokia.mafw.renderer.Mafw-Gst-Renderer-Plugin.gstrenderer /com/nokia/mafw/renderer/gstrenderer com.nokia.mafw.renderer.resume")
 	return 'Playing music.'
 
+def pause_music():
+	#Todo.
+	os.system("dbus-send --dest=com.nokia.mafw.renderer.Mafw-Gst-Renderer-Plugin.gstrenderer /com/nokia/mafw/renderer/gstrenderer com.nokia.mafw.renderer.pause")
+	return 'Okay.'
+
 def exists_in_order(a, b):
 	index = 0
 	for i in a:
@@ -233,7 +245,13 @@ def take_picture(input):
 			return sent.took_picture, 'self.display_picture("/home/user/MyDocs/DCIM/'+photoname+num+'.jpg")'
 
 def where_am_i(input):
-	return sent.heres_where_you_are, "gobject.timeout_add(os.system,'python /opt/modrana/modrana.py --center-on-position')"
+	return sent.heres_where_you_are, "gobject.timeout_add(500, os.system,'python /opt/modrana/modrana.py --center-on-position')"
+
+def food(input):
+	food = list(set(sent.food).intersection(set(input.split())))
+	food = food[0] if food else 'food'
+	#TODO - cmdline
+	return 'Let me search for '+food, "gobject.timeout_add(500, os.system, 'python /opt/modrana/modrana.py --local-search "+food+"')"
 
 def settings(input):
 	return "Ok."
@@ -347,8 +365,11 @@ def reminder_time(input):
 		minute = 60+minute
 	if type(hour)==bool:
 		hour = time.hour
+	tf = tempfile.NamedTemporaryFile()
+	tf.write('espeak "'+input+'"')
 	time = time.replace(hour=hour,minute=minute,second=0,microsecond=0)
-	os.system('echo \'espeak "'+input+'" > at')
+	os.system('at -t '+time.strftime('%Y%m%d%H%M')+' -f '+tf.name)
+
 	return str(time), None
 
 ###################################################
